pub struct ZipArchiveInner { /* private fields */ }Expand description
An inner store of metadata about a ZIP archive, which can be shared between readers.
Implementations
Sourceimpl ZipArchiveInner
impl ZipArchiveInner
Sourcepub fn find<'a>(
&'a self,
file_name: &'a [u8],
) -> Result<impl Iterator<Item = usize> + 'a>
pub fn find<'a>( &'a self, file_name: &'a [u8], ) -> Result<impl Iterator<Item = usize> + 'a>
Finds all the file indexes with the given file name. An iterator is returned because the ZIP specification allows for multiple files with the same file name, and most callers only need the first match.
pub fn cdrs(&self) -> &[CDR]
pub fn options(&self) -> &ZipOptions
pub fn ceocdr(&self) -> &CEOCDR