Module spec

Module spec 

A set of primitive types used to read and write ZIP archives.

Modules

constructs
A set of higher-level constructs wrapping the primitive headers & variable-length data.
extra
A set of extra-field specific headers and data structures.
headers1
A set of primitive headers.

Enums

ZipString
A string as stored within a ZIP archive.

Traits

KnownSize
An accessor trait for types that have a fixed size in bytes, such as headers.