ZipDateTime

Struct ZipDateTime 

pub struct ZipDateTime { /* private fields */ }
A date and time stored as per the MS-DOS representation used by ZIP files.

Implementations

Source

impl ZipDateTime

pub fn default_for_write() -> Self

Returns the current time if the jiff feature is enabled, otherwise the default of 1980-01-01.

pub fn year(&self) -> i32

Returns the year of this date & time.

pub fn month(&self) -> u32

Returns the month of this date & time.

pub fn day(&self) -> u32

Returns the day of this date & time.

pub fn hour(&self) -> u32

Returns the hour of this date & time.

pub fn minute(&self) -> u32

Returns the minute of this date & time.

pub fn second(&self) -> u32

Returns the second of this date & time.

Note that MS-DOS has a maximum granularity of two seconds.

pub fn as_jiff(&self) -> Result<DateTime, Error>

Available on crate feature jiff only.

Constructs Jiff’s civil::DateTime representation of this date & time.

Note that this requires the jiff feature.

pub fn from_jiff(date_time: &DateTime) -> Self

Available on crate feature jiff only.

Constructs this date & time from Jiff’s civil::DateTime representation.

Note that this requires the jiff feature.