ZipEntryBuilder

Struct ZipEntryBuilder 

pub struct ZipEntryBuilder(/* private fields */);
A builder for ZipEntry.

Implementations

Source

impl ZipEntryBuilder

pub fn new(filename: ZipString, compression: Compression) -> Self

Constructs a new builder which defines the raw underlying data of a ZIP entry.

A filename and compression method are needed to construct the builder as minimal parameters.

pub fn filename(self, filename: ZipString) -> Self

Sets the entry’s filename.

pub fn compression(self, compression: Compression) -> Self

Sets the entry’s compression method.

pub fn crc32<N: Into<u32>>(self, crc: N) -> Self

pub fn compressed_size<N: Into<u64>>(self, size: N) -> Self

pub fn uncompressed_size<N: Into<u64>>(self, size: N) -> Self

pub fn deflate_option(self, option: DeflateOption) -> Self

Available on crate features bzip2 or deflate or lzma or xz or zstd only.

Set the deflate compression option.

If the compression type isn’t deflate, this option has no effect.

pub fn attribute_compatibility( self, compatibility: AttributeCompatibility, ) -> Self

Sets the entry’s attribute host compatibility.

pub fn last_modification_date(self, date: ZipDateTime) -> Self

Sets the entry’s last modification date.

pub fn internal_file_attribute(self, attribute: u16) -> Self

Sets the entry’s internal file attribute.

pub fn external_file_attribute(self, attribute: u32) -> Self

Sets the entry’s external file attribute.

pub fn extra_fields(self, field: Vec<ExtraField>) -> Self

Sets the entry’s extra field data.

pub fn comment(self, comment: ZipString) -> Self

Sets the entry’s file comment.

pub fn unix_permissions(self, mode: u16) -> Self

Sets the entry’s Unix permissions mode.

If the attribute host compatibility isn’t set to Unix, this will have no effect.

pub fn current(&self) -> &ZipEntry

Returns a reference to the currently built entry.

pub fn build(self) -> ZipEntry

Consumes this builder and returns a final ZipEntry.

This is equivalent to:

let entry: ZipEntry = builder.into();