pub struct ZipDateTime { /* private fields */ }Expand description
A date and time stored as per the MS-DOS representation used by ZIP files.
Implementations
Sourceimpl ZipDateTime
impl ZipDateTime
Sourcepub fn default_for_write() -> Self
pub fn default_for_write() -> Self
Returns the current time if the jiff feature is enabled, otherwise the default of 1980-01-01.
Sourcepub fn second(&self) -> u32
pub fn second(&self) -> u32
Returns the second of this date & time.
Note that MS-DOS has a maximum granularity of two seconds.
Sourcepub fn as_jiff(&self) -> Result<DateTime, Error>
Available on crate feature jiff only.
pub fn as_jiff(&self) -> Result<DateTime, Error>
jiff only.Constructs Jiff’s civil::DateTime representation of this date & time.
Note that this requires the jiff feature.
Sourcepub fn from_jiff(date_time: &DateTime) -> Self
Available on crate feature jiff only.
pub fn from_jiff(date_time: &DateTime) -> Self
jiff only.Constructs this date & time from Jiff’s civil::DateTime representation.
Note that this requires the jiff feature.